@@ -47,22 +47,14 @@ const LRM = '\u200E';
 
 export class PlaceView extends Gtk.Box {
 
-    constructor(params) {
-        let place = params.place;
-        delete params.place;
-
-        let mapView = params.mapView;
-        delete params.mapView;
-
-        /* This mode is used in PlaceBar for inline current location details.
+    constructor({place, mapView, inlineMode, ...params}) {
+        /* inlineMode is used in PlaceBar for inline current location details.
            It hides the title box and decreases the start margin on the rows. */
-        let inlineMode = !!params.inlineMode;
-        delete params.inlineMode;
 
         super(params);
 
         this._place = place;
-        this._inlineMode = inlineMode;
+        this._inlineMode = !!inlineMode;
 
         let ui = Utils.getUIObject('place-view', [ 'bubble-main-box',
                                                    'bubble-spinner',
@@ -473,7 +465,8 @@ export class PlaceView extends Gtk.Box {
                            info: Translations.translateReligion(place.religion) });
         }
 
-        if (place.wiki && Wikipedia.isValidWikipedia(place.wiki)) {
+        if (place.wiki && Wikipedia.isValidWikipedia(place.wiki) ||
+            place.wikidata && Wikipedia.isValidWikidata(place.wikidata)) {
             content.push({ type: 'wikipedia', info: '' });
         }
 
@@ -585,7 +578,13 @@ export class PlaceView extends Gtk.Box {
         let content = this._createContent(place);
         this._attachContent(content);
 
-        if (place.wiki && Wikipedia.isValidWikipedia(place.wiki)) {
+        if (place.wikidata && Wikipedia.isValidWikidata(place.wikidata)) {
+            let defaultArticle =
+                place.wiki && Wikipedia.isValidWikipedia(place.wiki) ?
+                place.wiki : null;
+
+            this._requestWikidata(place.wikidata, defaultArticle);
+        } else if (place.wiki && Wikipedia.isValidWikipedia(place.wiki)) {
             this._requestWikipedia(place.wiki);
         }
 
@@ -600,6 +599,13 @@ export class PlaceView extends Gtk.Box {
                                    this._onThumbnailComplete.bind(this));
     }
 
+    _requestWikidata(wikidata, defaultArticle) {
+        Wikipedia.fetchArticleInfoForWikidata(
+            wikidata, defaultArticle, THUMBNAIL_FETCH_SIZE,
+            this._onWikiMetadataComplete.bind(this),
+            this._onThumbnailComplete.bind(this));
+    }
+
     _onThumbnailComplete(thumbnail) {
         this.thumbnail = thumbnail;
     }
